==> core_models-0.0.1.gem: app/models/core_models/misc/vat_rate.rb <==
module CoreModels
  class Misc::VatRate < ActiveRecord::Base
    belongs_to :country, :class_name => '::CoreModels::Base::Country'

    attr_accessible :applies_to, :standard_rate, :higher_rate, :registration_threshold
    attr_accessible :valid_from, :valid_until
    attr_accessible :notes

    attr_accessible :country, :country_id

    validates :country, :presence => true
    validates :valid_from, :presence => true
    validates :standard_rate, :presence => true

    #---------------------------------------------------------------------------

    #scope :rate_at,
    #  lambda {|date| {
    #    :conditions => "valid_from <= '#{date.to_s}' AND (valid_until IS NULL OR valid_until >= '#{date.to_s}')"
    #  } }

    #---------------------------------------------------------------------------

    def to_s
      display_value
    end

    def display_value(tax_class = nil)
      standard_rate.to_s + '%'
    end

    def long_display_value(tax_class)
      display_value = country.code
      display_value += ' (' + tax_class.name + ')'
      display_value += ' ' + display_value(tax_class)
      display_value
    end

    def self.default
      ::CoreModels::Misc::VatRate.current_rate
    end

    def self.rate_at(date)
      self.where( "valid_from <= '#{date.to_s}' AND (valid_until IS NULL OR valid_until >= '#{date.to_s}')" ).first
    end

    def self.current_rate
      self.rate_at( Date.current )
    end

    #---------------------------------------------------------------------------

    private

  end
end

==> core_models-0.1.0.gem: app/models/core_models/misc/vat_rate.rb <==
module CoreModels
  class Misc::VatRate < ActiveRecord::Base
    belongs_to :country, :class_name => '::CoreModels::Base::Country'

    #attr_accessible :applies_to, :standard_rate, :higher_rate, :registration_threshold
    #attr_accessible :valid_from, :valid_until
    #attr_accessible :notes

    #attr_accessible :country, :country_id

    validates :country, :presence => true
    validates :valid_from, :presence => true
    validates :standard_rate, :presence => true

    #---------------------------------------------------------------------------

    #scope :rate_at,
    #  lambda {|date| {
    #    :conditions => "valid_from <= '#{date.to_s}' AND (valid_until IS NULL OR valid_until >= '#{date.to_s}')"
    #  } }

    #---------------------------------------------------------------------------

    def to_s
      display_value
    end

    def display_value(tax_class = nil)
      standard_rate.to_s + '%'
    end

    def long_display_value(tax_class)
      display_value = country.code
      display_value += ' (' + tax_class.name + ')'
      display_value += ' ' + display_value(tax_class)
      display_value
    end

    def self.default
      ::CoreModels::Misc::VatRate.current_rate
    end

    def self.rate_at(date)
      self.where( "valid_from <= '#{date.to_s}' AND (valid_until IS NULL OR valid_until >= '#{date.to_s}')" ).first
    end

    def self.current_rate
      self.rate_at( Date.current )
    end

    #---------------------------------------------------------------------------

    private

  end
end
